@@ -58,8 +58,10 @@
 #define EOVERFLOW EINVAL
 #endif
 
+#undef poll
+
 int
-poll (pfd, nfd, timeout)
+rpl_poll (pfd, nfd, timeout)
      struct pollfd *pfd;
      nfds_t nfd;
      int timeout;
@@ -68,7 +70,6 @@ poll (pfd, nfd, timeout)
   struct timeval tv, *ptv;
   int maxfd, rc, happened;
   nfds_t i;
-  char data[64];
 
 #ifdef _SC_OPEN_MAX
   if (nfd > sysconf (_SC_OPEN_MAX))
@@ -166,14 +167,31 @@ poll (pfd, nfd, timeout)
 	      /* support for POLLHUP.  */
 #if defined __MACH__ && defined __APPLE__
 	      /* There is a bug in Mac OS X that causes it to ignore MSG_PEEK for
-		 some kinds of descriptors.  Use FIONREAD to emulate POLLHUP,
-		 but not on TTYs or it screws up the TTY attributes... */
+		 some kinds of descriptors.  Use FIONREAD to emulate POLLHUP.
+		 It is still not completely POSIX compliant (it does not fully
+		 work on TTYs), but at least it does not delete data!  For other
+		 platforms, we still use MSG_PEEK because it was proved to be
+		 reliable, and I a leery of changing it.  */
 	      do
 		r = ioctl (pfd[i].fd, FIONREAD, &avail);
 	      while (r == -1 && (errno == EAGAIN || errno == EINTR));
 	      if (avail < 0)
 	        avail = 0;
+
+	      if (avail == 0)
+	        {
+		  /* The above fails for listening sockets; of course, BSD
+		     derivatives have a bug and don't expose SO_ACCEPTCONN to
+		     user programs!  So we rely on Apple's broken poll(2) in
+		     this case.  It can't be worse than what we did so far.  */
+		  struct pollfd pfd_for_apple_poll = pfd[0];
+		  extern int poll (struct pollfd *, nfds_t, int);
+		  r = poll (&pfd_for_apple_poll, 1, 0);
+		  if (r != -1 && (pfd_for_apple_poll.revents & POLLHUP) == 0)
+		    avail = 1;
+		}
 #else
+	      char data[64];
 	      r = recv (pfd[i].fd, data, 64, MSG_PEEK);
 	      if (r == -1)
 		{
@@ -188,7 +206,7 @@ poll (pfd, nfd, timeout)
 	      /* An hung up descriptor does not increase the return value! */
 	      if (avail == 0)
 		pfd[i].revents |= POLLHUP;
-	      else
+	      else if (avail != -1)
 		happened |= POLLIN | POLLRDNORM;
 	    }
 
