@@ -7,7 +7,7 @@
 
 /***********************************************************************
  *
- * Copyright 2000, 2001, 2002, 2003, 2005 Free Software Foundation, Inc.
+ * Copyright 2000, 2001, 2002, 2003, 2005, 2006 Free Software Foundation, Inc.
  * Written by Steve Byrne.
  *
  * This file is part of GNU Smalltalk.
@@ -17,6 +17,28 @@
  * Software Foundation; either version 2, or (at your option) any later 
  * version.
  * 
+ * Linking GNU Smalltalk statically or dynamically with other modules is
+ * making a combined work based on GNU Smalltalk.  Thus, the terms and
+ * conditions of the GNU General Public License cover the whole
+ * combination.
+ *
+ * In addition, as a special exception, the Free Software Foundation
+ * give you permission to combine GNU Smalltalk with free software
+ * programs or libraries that are released under the GNU LGPL and with
+ * independent programs running under the GNU Smalltalk virtual machine.
+ *
+ * You may copy and distribute such a system following the terms of the
+ * GNU GPL for GNU Smalltalk and the licenses of the other code
+ * concerned, provided that you include the source code of that other
+ * code when and as the GNU GPL requires distribution of source code.
+ *
+ * Note that people who make modified versions of GNU Smalltalk are not
+ * obligated to grant this special exception for their modified
+ * versions; it is their choice whether to do so.  The GNU General
+ * Public License gives permission to release a modified version without
+ * this exception; this exception also makes it possible to release a
+ * modified version which carries forward this exception.
+ *
  * GNU Smalltalk is distributed in the hope that it will be useful, but WITHOUT
  * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or 
  * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
@@ -143,6 +165,8 @@ OOP _gst_time_class = NULL;
 OOP _gst_token_stream_class = NULL;
 OOP _gst_true_class = NULL;
 OOP _gst_undefined_object_class = NULL;
+OOP _gst_unicode_character_class = NULL;
+OOP _gst_unicode_string_class = NULL;
 OOP _gst_variable_binding_class = NULL;
 OOP _gst_write_stream_class = NULL;
 OOP _gst_processor_oop = NULL;
@@ -246,9 +270,6 @@ static void init_primitives_dictionary (void);
 static void init_c_symbols (void);
 
 static const char *feature_strings[] = {
-#ifdef MACHINE_DEFINES
-  MACHINE_DEFINES
-#endif
 #ifdef ENABLE_DLD
     "DLD",
 #endif
@@ -293,7 +314,11 @@ static const class_definition class_info[] = {
 
   {&_gst_char_class, &_gst_magnitude_class,
    ISP_FIXED, 1,
-   "Character", "asciiValue", "Table", NULL },
+   "Character", "codePoint", "Table UpperTable LowerTable", NULL },
+
+  {&_gst_unicode_character_class, &_gst_char_class,
+   ISP_FIXED, 0,
+   "UnicodeCharacter", NULL, NULL, NULL },
 
   {&_gst_time_class, &_gst_magnitude_class,
    ISP_FIXED, 1,
@@ -421,11 +446,15 @@ static const class_definition class_info[] = {
    "CharacterArray", NULL, NULL, NULL },
 
   {&_gst_string_class, &_gst_character_array_class,
-   ISP_UCHAR, 0,
+   ISP_CHARACTER, 0,
    "String", NULL, NULL, NULL },
 
+  {&_gst_unicode_string_class, &_gst_character_array_class,
+   ISP_UTF32, 0,
+   "UnicodeString", NULL, NULL, NULL },
+
   {&_gst_symbol_class, &_gst_string_class,
-   ISP_UCHAR, 0,
+   ISP_CHARACTER, 0,
    "Symbol", NULL, NULL, NULL },
 
   {&_gst_byte_array_class, &_gst_arrayed_collection_class,
@@ -548,8 +577,8 @@ static const class_definition class_info[] = {
    "ByteStream", NULL, NULL, NULL },
 
   {&_gst_file_descriptor_class, &_gst_byte_stream_class,
-   ISP_FIXED, 4,
-   "FileDescriptor", "file name isPipe atEnd", NULL, NULL },
+   ISP_FIXED, 5,
+   "FileDescriptor", "file name isPipe atEnd peek", NULL, NULL },
 
   {&_gst_file_stream_class, &_gst_file_descriptor_class,
    ISP_FIXED, 2,
@@ -677,11 +706,12 @@ static const class_definition class_info[] = {
 };
 
 signed char _gst_log2_sizes[32] = {
-  0, -1, 0, -1, 
+  0, -1, 0, -1, 0, -1,
   1, -1, 1, -1, 
   2, -1, 2, -1, 2, -1, 
   3, -1, 3, -1, 3, -1,
-  -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
+  2, -1,
+  -1, -1, -1, -1, -1, -1,
   sizeof (long) == 4 ? 2 : 3, -1
 };
 
@@ -693,7 +723,7 @@ void
 init_proto_oops()
 {
   gst_namespace smalltalkDictionary;
-  mst_Object symbolTable, processorScheduler;
+  gst_object symbolTable, processorScheduler;
   int numWords;
 
   /* We can do this now that the classes are defined */
@@ -826,7 +856,7 @@ create_metaclass (OOP class_oop,
 {
   gst_class class;
   gst_metaclass metaclass;
-  mst_Object subClasses;
+  gst_object subClasses;
   OOP superClassOOP;
 
   superClassOOP = SUPERCLASS (class_oop);
@@ -940,7 +970,7 @@ void
 init_smalltalk_dictionary (void)
 {
   OOP featuresArrayOOP;
-  mst_Object featuresArray;
+  gst_object featuresArray;
   char fullVersionString[200];
   int i, numFeatures;
 
@@ -1077,7 +1107,7 @@ init_c_symbols ()
   NAMESPACE_AT_PUT (cSymbolsOOP, _gst_intern_string ("CDoubleMaxExp"),
 		    FROM_INT (DBL_MAX_EXP));
   NAMESPACE_AT_PUT (cSymbolsOOP, _gst_intern_string ("CDoubleAlignment"),
-		    FROM_INT (DOUBLE_ALIGNMENT));
+		    FROM_INT (ALIGNOF_DOUBLE));
 
   NAMESPACE_AT_PUT (cSymbolsOOP, _gst_intern_string ("CFloatPInf"),
 		    floate_new ((float) INFINITY));
@@ -1119,7 +1149,7 @@ init_c_symbols ()
   NAMESPACE_AT_PUT (cSymbolsOOP, _gst_intern_string ("CLongDoubleMaxExp"),
 		    FROM_INT (LDBL_MAX_EXP));
   NAMESPACE_AT_PUT (cSymbolsOOP, _gst_intern_string ("CLongDoubleAlignment"),
-		    FROM_INT (LONG_DOUBLE_ALIGNMENT));
+		    FROM_INT (ALIGNOF_LONG_DOUBLE));
 }
 
 void
@@ -1326,7 +1356,7 @@ _gst_valid_class_method_dictionary (OOP class_oop)
   if (IS_NIL (class->methodDictionary))
     {
       OOP identDict;
-      mst_Object obj;
+      gst_object obj;
       identDict = identity_dictionary_new (32);
       obj = OOP_TO_OBJ (identDict);
       obj->objClass = _gst_method_dictionary_class;
@@ -1449,11 +1479,11 @@ find_key_or_nil (OOP dictionaryOOP,
 {
   size_t count, numFields, numFixedFields;
   intptr_t index;
-  mst_Object dictionary;
+  gst_object dictionary;
   OOP associationOOP;
   gst_association association;
 
-  dictionary = (mst_Object) OOP_TO_OBJ (dictionaryOOP);
+  dictionary = (gst_object) OOP_TO_OBJ (dictionaryOOP);
   numFixedFields = OOP_FIXED_FIELDS (dictionaryOOP);
   numFields = NUM_WORDS (dictionary) - numFixedFields;
   index = scramble (OOP_INDEX (keyOOP));
@@ -1481,10 +1511,10 @@ find_key_or_nil (OOP dictionaryOOP,
   abort ();
 }
 
-mst_Object
+gst_object
 _gst_grow_dictionary (OOP oldDictionaryOOP)
 {
-  mst_Object oldDictionary, dictionary;
+  gst_object oldDictionary, dictionary;
   size_t oldNumFields, numFields, i, index, numFixedFields;
   OOP associationOOP;
   gst_association association;
@@ -1755,7 +1785,7 @@ _gst_dictionary_add (OOP dictionaryOOP,
 {
   intptr_t index;
   gst_association association;
-  mst_Object dictionary;
+  gst_object dictionary;
   gst_dictionary dict;
   OOP value;
   inc_ptr incPtr;		/* I'm not sure clients are protecting
@@ -1796,7 +1826,7 @@ _gst_dictionary_add (OOP dictionaryOOP,
 OOP
 _gst_object_copy (OOP oop)
 {
-  mst_Object old, new;
+  gst_object old, new;
   OOP newOOP;
   size_t numFields;
 
@@ -1837,7 +1867,7 @@ _gst_string_new (const char *s)
       string = (gst_string) new_instance_with (_gst_string_class, len,
 					       &stringOOP);
 
-      strncpy (string->chars, s, len);
+      memcpy (string->chars, s, len);
     }
   else
     string = (gst_string) new_instance_with (_gst_string_class, 0,
@@ -1845,6 +1875,33 @@ _gst_string_new (const char *s)
   return (stringOOP);
 }
 
+OOP
+_gst_unicode_string_new (const wchar_t *s)
+{
+  int i;
+  gst_unicode_string string;
+  size_t len;
+  OOP stringOOP;
+
+  if (s)
+    {
+      len = wcslen (s);
+      string = (gst_unicode_string)
+	new_instance_with (_gst_unicode_string_class, len, &stringOOP);
+
+      if (sizeof (wchar_t) == sizeof (string->chars[0]))
+	memcpy (string->chars, s, len * sizeof (wchar_t));
+      else
+	for (i = 0; i < len; i++)
+	  string->chars[i] = *s++;
+    }
+  else
+    string = (gst_unicode_string)
+      new_instance_with (_gst_unicode_string_class, 0, &stringOOP);
+
+  return (stringOOP);
+}
+
 OOP
 _gst_counted_string_new (const char *s,
 			 size_t len)
@@ -1871,6 +1928,16 @@ _gst_set_oopstring (OOP stringOOP,
   _gst_swap_objects (stringOOP, newStringOOP);
 }
 
+void
+_gst_set_oop_unicode_string (OOP unicodeStringOOP,
+			     const wchar_t *s)
+{
+  OOP newStringOOP;
+
+  newStringOOP = _gst_unicode_string_new (s);
+  _gst_swap_objects (unicodeStringOOP, newStringOOP);
+}
+
 char *
 _gst_to_cstring (OOP stringOOP)
 {
@@ -1881,7 +1948,28 @@ _gst_to_cstring (OOP stringOOP)
   string = (gst_string) OOP_TO_OBJ (stringOOP);
   len = oop_num_fields (stringOOP);
   result = (char *) xmalloc (len + 1);
-  strncpy (result, string->chars, len);
+  memcpy (result, string->chars, len);
+  result[len] = '\0';
+
+  return (result);
+}
+
+wchar_t *
+_gst_to_wide_cstring (OOP stringOOP)
+{
+  wchar_t *result, *p;
+  size_t len;
+  gst_unicode_string string;
+  int i;
+
+  string = (gst_unicode_string) OOP_TO_OBJ (stringOOP);
+  len = oop_num_fields (stringOOP);
+  result = (wchar_t *) xmalloc (len + 1);
+  if (sizeof (wchar_t) == 4)
+    memcpy (result, string->chars, len * sizeof (wchar_t));
+  else
+    for (p = result, i = 0; i < len; i++)
+      *p++ = string->chars[i];
   result[len] = '\0';
 
   return (result);
