@@ -7,7 +7,7 @@
 
 /***********************************************************************
  *
- * Copyright 1988,89,90,91,92,94,95,99,2000,2001,2002
+ * Copyright 1988,89,90,91,92,94,95,99,2000,2001,2002,2006
  * Free Software Foundation, Inc.
  * Written by Steve Byrne.
  *
@@ -18,6 +18,28 @@
  * Software Foundation; either version 2, or (at your option) any later 
  * version.
  * 
+ * Linking GNU Smalltalk statically or dynamically with other modules is
+ * making a combined work based on GNU Smalltalk.  Thus, the terms and
+ * conditions of the GNU General Public License cover the whole
+ * combination.
+ *
+ * In addition, as a special exception, the Free Software Foundation
+ * give you permission to combine GNU Smalltalk with free software
+ * programs or libraries that are released under the GNU LGPL and with
+ * independent programs running under the GNU Smalltalk virtual machine.
+ *
+ * You may copy and distribute such a system following the terms of the
+ * GNU GPL for GNU Smalltalk and the licenses of the other code
+ * concerned, provided that you include the source code of that other
+ * code when and as the GNU GPL requires distribution of source code.
+ *
+ * Note that people who make modified versions of GNU Smalltalk are not
+ * obligated to grant this special exception for their modified
+ * versions; it is their choice whether to do so.  The GNU General
+ * Public License gives permission to release a modified version without
+ * this exception; this exception also makes it possible to release a
+ * modified version which carries forward this exception.
+ *
  * GNU Smalltalk is distributed in the hope that it will be useful, but WITHOUT
  * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or 
  * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
@@ -339,15 +361,17 @@ enum {
   ISP_FIXED = 0,
   ISP_SCHAR = 32,
   ISP_UCHAR = 34,
-  ISP_SHORT = 36,
-  ISP_USHORT = 38,
-  ISP_INT = 40,
-  ISP_UINT = 42,
-  ISP_FLOAT = 44,
-  ISP_INT64 = 46,
-  ISP_UINT64 = 48,
-  ISP_DOUBLE = 50,
-  ISP_LAST_SCALAR = 50,
+  ISP_CHARACTER = 36,
+  ISP_SHORT = 38,
+  ISP_USHORT = 40,
+  ISP_INT = 42,
+  ISP_UINT = 44,
+  ISP_FLOAT = 46,
+  ISP_INT64 = 48,
+  ISP_UINT64 = 50,
+  ISP_DOUBLE = 52,
+  ISP_UTF32 = 54,
+  ISP_LAST_SCALAR = 54,
   ISP_POINTER = 62,
 
 #if SIZEOF_OOP == 8
@@ -566,30 +590,10 @@ extern OOP _gst_nil_oop
 #include <limits.h>
 #include <poll.h>
 #include <ctype.h>
-
-#ifdef HAVE_DIRENT_H
-# include <dirent.h>
-# define NAMLEN(dirent) strlen((dirent)->d_name)
-#else
-# define dirent direct
-# define NAMLEN(dirent) (dirent)->d_namlen
-# ifdef HAVE_SYS_NDIR_H
-#  include <sys/ndir.h>
-# endif
-# ifdef HAVE_SYS_DIR_H
-#  include <sys/dir.h>
-# endif
-# ifdef HAVE_NDIR_H
-#  include <ndir.h>
-# endif
-#endif
-
-#if defined(HAVE_SYS_TIME_H) || defined(TIME_WITH_SYS_TIME)
-# include <sys/time.h>
-#endif
-#if !defined(HAVE_SYS_TIME_H) || defined(TIME_WITH_SYS_TIME)
-# include <time.h>
-#endif
+#include <wchar.h>
+#include <dirent.h>
+#include <sys/time.h>
+#include <time.h>
 
 #ifdef HAVE_SYS_RESOURCE_H
 #include <sys/resource.h>
@@ -611,7 +615,14 @@ extern OOP _gst_nil_oop
 #include <sys/mman.h>
 #endif
 
-#include "stdintx.h"
+#ifdef HAVE_STDINT_H
+#include <stdint.h>
+#endif
+
+#ifdef HAVE_INTTYPES_H
+#include <inttypes.h>
+#endif
+
 #include "ansidecl.h"
 #include "signalx.h"
 #include "mathl.h"
@@ -647,7 +658,6 @@ extern OOP _gst_nil_oop
 #include "mpz.h"
 #include "print.h"
 #include "security.h"
-#include "match.h"
 
 /* Include this last, it has the bad habit of #defining printf
    and this fools gcc's __attribute__ (format) */
@@ -655,13 +665,13 @@ extern OOP _gst_nil_oop
 
 #undef obstack_init
 #define obstack_init(h)                                         \
-  _obstack_begin ((h), 0, LONG_DOUBLE_ALIGNMENT,                \
+  _obstack_begin ((h), 0, ALIGNOF_LONG_DOUBLE,                \
                   (void *(*) (long)) obstack_chunk_alloc,       \
                   (void (*) (void *)) obstack_chunk_free)
 
 #undef obstack_begin
 #define obstack_begin(h, size)                                  \
-  _obstack_begin ((h), (size), LONG_DOUBLE_ALIGNMENT,           \
+  _obstack_begin ((h), (size), ALIGNOF_LONG_DOUBLE,           \
                   (void *(*) (long)) obstack_chunk_alloc,       \
                   (void (*) (void *)) obstack_chunk_free)
 
