@@ -7,7 +7,7 @@
 
 /***********************************************************************
  *
- * Copyright 2001, 2002, 2003 Free Software Foundation, Inc.
+ * Copyright 2001, 2002, 2003, 2006 Free Software Foundation, Inc.
  * Written by Paolo Bonzini.
  *
  * This file is part of GNU Smalltalk.
@@ -17,6 +17,28 @@
  * Software Foundation; either version 2, or (at your option) any later 
  * version.
  * 
+ * Linking GNU Smalltalk statically or dynamically with other modules is
+ * making a combined work based on GNU Smalltalk.  Thus, the terms and
+ * conditions of the GNU General Public License cover the whole
+ * combination.
+ *
+ * In addition, as a special exception, the Free Software Foundation
+ * give you permission to combine GNU Smalltalk with free software
+ * programs or libraries that are released under the GNU LGPL and with
+ * independent programs running under the GNU Smalltalk virtual machine.
+ *
+ * You may copy and distribute such a system following the terms of the
+ * GNU GPL for GNU Smalltalk and the licenses of the other code
+ * concerned, provided that you include the source code of that other
+ * code when and as the GNU GPL requires distribution of source code.
+ *
+ * Note that people who make modified versions of GNU Smalltalk are not
+ * obligated to grant this special exception for their modified
+ * versions; it is their choice whether to do so.  The GNU General
+ * Public License gives permission to release a modified version without
+ * this exception; this exception also makes it possible to release a
+ * modified version which carries forward this exception.
+ *
  * GNU Smalltalk is distributed in the hope that it will be useful, but WITHOUT
  * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or 
  * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
@@ -177,7 +199,7 @@ extern off_t _gst_get_cur_file_pos (void)
   ATTRIBUTE_HIDDEN;
 
 /* Returns an OOP containing the string of the topmost stream if it is
-   of type STREAM_STRING; nil otherwise.  */
+   a STREAM_STRING, STREAM_OOP or STREAM_READLINE; nil otherwise.  */
 extern OOP _gst_get_cur_string (void)
   ATTRIBUTE_PURE 
   ATTRIBUTE_HIDDEN;
@@ -194,13 +216,6 @@ extern void _gst_add_symbol_completion (const char *str,
 					int len) 
   ATTRIBUTE_HIDDEN;
 
-/* Returns a Smalltalk String for the data read by the Readline
-   interface, or nil if the stream does not have type
-   STREAM_READLINE.  */
-extern OOP _gst_get_cur_readline (void)
-  ATTRIBUTE_PURE 
-  ATTRIBUTE_HIDDEN;
-
 /* Add 1 to the completion-enabling flag.  The flag starts at 1
    (completions are active) and completions are enabled until the flag
    falls below this value.  */
