@@ -7,7 +7,7 @@
 
 /***********************************************************************
  *
- * Copyright 1988,89,90,91,92,94,95,99,2000,2001,2002
+ * Copyright 1988,89,90,91,92,94,95,99,2000,2001,2002,2006
  * Free Software Foundation, Inc.
  * Written by Steve Byrne.
  *
@@ -18,6 +18,28 @@
  * Software Foundation; either version 2, or (at your option) any later 
  * version.
  * 
+ * Linking GNU Smalltalk statically or dynamically with other modules is
+ * making a combined work based on GNU Smalltalk.  Thus, the terms and
+ * conditions of the GNU General Public License cover the whole
+ * combination.
+ *
+ * In addition, as a special exception, the Free Software Foundation
+ * give you permission to combine GNU Smalltalk with free software
+ * programs or libraries that are released under the GNU LGPL and with
+ * independent programs running under the GNU Smalltalk virtual machine.
+ *
+ * You may copy and distribute such a system following the terms of the
+ * GNU GPL for GNU Smalltalk and the licenses of the other code
+ * concerned, provided that you include the source code of that other
+ * code when and as the GNU GPL requires distribution of source code.
+ *
+ * Note that people who make modified versions of GNU Smalltalk are not
+ * obligated to grant this special exception for their modified
+ * versions; it is their choice whether to do so.  The GNU General
+ * Public License gives permission to release a modified version without
+ * this exception; this exception also makes it possible to release a
+ * modified version which carries forward this exception.
+ *
  * GNU Smalltalk is distributed in the hope that it will be useful, but WITHOUT
  * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or 
  * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
@@ -44,7 +66,7 @@
    True, False, and UndefinedObject (nil) oops, which are
    built-ins.  */
 #define INITIAL_OOP_TABLE_SIZE	(1024 * 128 + BUILTIN_OBJECT_BASE)
-#define MAX_OOP_TABLE_SIZE	(sizeof(struct OOP) << 20)
+#define MAX_OOP_TABLE_SIZE	(sizeof(struct oop_s) << 20)
 
 /* The number of free OOPs under which we trigger GCs.  0 is not
    enough because _gst_scavenge might still need some oops in
@@ -171,7 +193,7 @@ struct memory_space
      Some of the bits indicate the difference between the allocated length
      (stored in the object itself), and the real length, because variable
      byte objects may not be an even multiple of sizeof(PTR).  */
-  struct OOP *ot, *ot_base;
+  struct oop_s *ot, *ot_base;
 
   /* The number of OOPs in the free list and in the full OOP
      table.  num_free_oops is only correct after a GC!  */
@@ -370,19 +392,19 @@ extern void _gst_inc_grow_registry (void)
 
    The pointer to the object data is returned, the OOP is
    stored in P_OOP.  */
-extern mst_Object _gst_alloc_obj (size_t size,
+extern gst_object _gst_alloc_obj (size_t size,
 				  OOP *p_oop) 
   ATTRIBUTE_HIDDEN;
 
 /* The same, but for an oldspace object */
-extern mst_Object _gst_alloc_old_obj (size_t size,
+extern gst_object _gst_alloc_old_obj (size_t size,
 				      OOP *p_oop) 
   ATTRIBUTE_HIDDEN;
 
 /* Allocate and return space for an object of SIZE words, without
    creating an OOP.  This is a special operation that is only needed
    at bootstrap time, so it does not care about garbage collection.  */
-extern mst_Object _gst_alloc_words (size_t size) 
+extern gst_object _gst_alloc_words (size_t size) 
   ATTRIBUTE_HIDDEN;
 
 /* Grows the allocated memory to SPACESIZE bytes, if it's not there
