@@ -7,7 +7,7 @@
 
 /***********************************************************************
  *
- * Copyright 1988,89,90,91,92,94,95,99,2000,2001,2002,2003,2005
+ * Copyright 1988,89,90,91,92,94,95,99,2000,2001,2002,2003,2005,2006
  * Free Software Foundation, Inc.
  * Written by Steve Byrne.
  *
@@ -18,6 +18,28 @@
  * Software Foundation; either version 2, or (at your option) any later 
  * version.
  * 
+ * Linking GNU Smalltalk statically or dynamically with other modules is
+ * making a combined work based on GNU Smalltalk.  Thus, the terms and
+ * conditions of the GNU General Public License cover the whole
+ * combination.
+ *
+ * In addition, as a special exception, the Free Software Foundation
+ * give you permission to combine GNU Smalltalk with free software
+ * programs or libraries that are released under the GNU LGPL and with
+ * independent programs running under the GNU Smalltalk virtual machine.
+ *
+ * You may copy and distribute such a system following the terms of the
+ * GNU GPL for GNU Smalltalk and the licenses of the other code
+ * concerned, provided that you include the source code of that other
+ * code when and as the GNU GPL requires distribution of source code.
+ *
+ * Note that people who make modified versions of GNU Smalltalk are not
+ * obligated to grant this special exception for their modified
+ * versions; it is their choice whether to do so.  The GNU General
+ * Public License gives permission to release a modified version without
+ * this exception; this exception also makes it possible to release a
+ * modified version which carries forward this exception.
+ *
  * GNU Smalltalk is distributed in the hope that it will be useful, but WITHOUT
  * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or 
  * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
@@ -143,6 +165,7 @@ OOP _gst_string_out_symbol = NULL;
 OOP _gst_string_symbol = NULL;
 OOP _gst_super_symbol = NULL;
 OOP _gst_symbol_symbol = NULL;
+OOP _gst_symbol_out_symbol = NULL;
 OOP _gst_symbol_table = NULL;
 OOP _gst_terminate_symbol = NULL;
 OOP _gst_this_context_symbol = NULL;
@@ -165,6 +188,9 @@ OOP _gst_variadic_smalltalk_symbol = NULL;
 OOP _gst_variadic_symbol = NULL;
 OOP _gst_vm_primitives_symbol = NULL;
 OOP _gst_void_symbol = NULL;
+OOP _gst_wchar_symbol = NULL;
+OOP _gst_wstring_symbol = NULL;
+OOP _gst_wstring_out_symbol = NULL;
 OOP _gst_while_false_colon_symbol = NULL;
 OOP _gst_while_false_symbol = NULL;
 OOP _gst_while_true_colon_symbol = NULL;
@@ -323,6 +349,7 @@ static const symbol_info sym_info[] = {
   {&_gst_string_symbol, "string"},
   {&_gst_super_symbol, "super"},
   {&_gst_symbol_symbol, "symbol"},
+  {&_gst_symbol_out_symbol, "symbolOut"},
   {&_gst_terminate_symbol, "__terminate"},
   {&_gst_this_context_symbol, "thisContext"},
   {&_gst_times_symbol, "*"},
@@ -344,6 +371,9 @@ static const symbol_info sym_info[] = {
   {&_gst_variadic_smalltalk_symbol, "variadicSmalltalk"},
   {&_gst_vm_primitives_symbol, "VMPrimitives"},
   {&_gst_void_symbol, "void"},
+  {&_gst_wchar_symbol, "wchar"},
+  {&_gst_wstring_symbol, "wstring"},
+  {&_gst_wstring_out_symbol, "wstringOut"},
   {&_gst_while_false_colon_symbol, "whileFalse:"},
   {&_gst_while_false_symbol, "whileFalse"},
   {&_gst_while_true_colon_symbol, "whileTrue:"},
@@ -819,7 +849,7 @@ _gst_make_instance_variable_array (OOP superclassOOP,
   int index, numInstanceVars, superInstanceVars;
   const char *p;
   inc_ptr incPtr;
-  mst_Object array;
+  gst_object array;
 
   if (variableString == NULL)
     variableString = "";
@@ -913,7 +943,7 @@ OOP
 _gst_make_pool_array (const char * poolNames)
 {
   OOP poolsOOP, name;
-  mst_Object pools;
+  gst_object pools;
   int numPools, i;
   const char *p, *e;
   inc_ptr incPtr;
