@@ -24,7 +24,7 @@
 //
 // You should have received a copy of the GNU General Public License along with
 // GNU Smalltalk; see the file COPYING.	 If not, write to the Free Software
-// Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+// Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 //
 ///////////////////////////////////////////////////////////////////////
 
@@ -517,6 +517,8 @@ bytecode_fast_send bc21 (21, "SEND_SPECIAL", "NOT_NIL_SPECIAL(*)");
 bytecode_fast_send bc22 (22, "SEND_SPECIAL", "VALUE_SPECIAL(*)");
 bytecode_fast_send bc23 (23, "SEND_SPECIAL", "VALUE_COLON_SPECIAL(*)");
 bytecode_fast_send bc24 (24, "SEND_SPECIAL", "SAME_OBJECT_SPECIAL(*)");
+bytecode_fast_send bc25 (25, "SEND_SPECIAL", "JAVA_AS_INT_SPECIAL(*)");
+bytecode_fast_send bc26 (26, "SEND_SPECIAL", "JAVA_AS_LONG_SPECIAL(*)");
 bytecode_send bc28 (28, "SEND", "SEND(*)");
 bytecode_send bc29 (29, "SEND", "SEND_SUPER(*)");
 bytecode_send_imm bc30 (30, "SEND_IMMEDIATE", "SEND_IMMEDIATE(*)");
